@@ -1,6 +1,6 @@
-package Weaving::Tablet::Tk;
+package Snartemo::Tk;
 
-use Weaving::Tablet;
+use Snartemo;
 require Tk::HList;
 require Tk::FileSelect;
 require Tk::FontDialog;
@@ -10,14 +10,14 @@ use Data::Dumper;
 use strict;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $AUTOLOAD);
 
-@ISA = qw(Weaving::Tablet);
+@ISA = qw(Snartemo);
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 @EXPORT = qw(
 	
 );
-$VERSION = '0.8.2';
+$VERSION = '0.6';
 
 
 # Preloaded methods go here.
@@ -1851,14 +1851,14 @@ __END__
 
 =head1 NAME
 
-Weaving::Tablet::Tk - Tk user interface to Weaving::Tablet designer
+Snartemo::Tk - Tk user interface to Snartemo designer
 
 =head1 SYNOPSIS
 
-  use Weaving::Tablet::Tk;
+  use Snartemo::Tk;
   use Tk;
-  my $pattern = Weaving::Tablet::Tk->new_pattern(mw => $mw, file => $file);
-  my $pattern2 = Weaving::Tablet::Tk->new_pattern(mw => $mw, cards => $cards, rows => $rows);
+  my $pattern = Snartemo::Tk->new_pattern(mw => $mw, file => $file);
+  my $pattern2 = Snartemo::Tk->new_pattern(mw => $mw, cards => $cards, rows => $rows);
   
   $pattern->canvas # get the drawing area
   $pattern->window # get the toplevel window
@@ -1867,9 +1867,9 @@ Weaving::Tablet::Tk - Tk user interface to Weaving::Tablet designer
 
 =head1 DESCRIPTION
 
-Weaving::Tablet::Tk wraps a Tk user interface around the core routines in Weaving::Tablet.
+Snartemo::Tk wraps a Tk user interface around the core routines in Snartemo.
 
-Weaving::Tablet::Tk is a subclass of Weaving::Tablet.
+Snartemo::Tk is a subclass of Snartemo.
 
 =head2 new
 
