@@ -7,11 +7,10 @@
 # (It may become useful if the test is moved to ./t subdirectory.)
 BEGIN { $| = 1; print "1..1\n"; }
 END {print "not ok 1\n" unless $loaded;}
-use Weaving::Tablet::Tk;
+use Snartemo::Tk;
 $loaded = 1;
 print "ok 1\n";
 
-exit;
 ######################### End of black magic.
 
 # Insert your test code below (better if it prints "ok 13"
